%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LaTeX class file GKB100.cls
% sets definitions and format for abstracts submitted to
% the GKB100: Fluid mechanics in the spirit of G. K. Batchelor
% 15-18 March 2020, DAMTP, Centre for Mathematical Sciences, Cambridge, UK 
%
% P. F Linden
% DAMTP, University of Cambridge
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
\NeedsTeXFormat{LaTeX2e}
%
\ProvidesClass{GKB100}[2014/09/03]
%
\DeclareOption*{
 \ClassWarning{GKB100}{Unknown Option '\CurrentOption'}}
\ProcessOptions\relax
\LoadClass[10pt,a4paper,oneside]{article}
\RequirePackage{color}
%
% Fonts
\renewcommand*\sfdefault{phv}\normalfont
\renewcommand*\familydefault{\sfdefault}
\fontfamily{phv}\selectfont
\definecolor{grey0}{gray}{0.4}
%
% Page Layout
\setlength{\oddsidemargin}{0mm}
\setlength{\textwidth}{157mm}
\setlength{\textheight}{27.6cm}
\setlength{\voffset}{-0.75in}
\setlength{\headsep}{0mm}
\setlength{\topmargin}{0mm}
\setlength{\headheight}{0mm}
\setlength{\parskip}{3pt}
\setlength{\parindent}{0pt}
%
% Head and foot
\pagestyle{empty}
\newcommand{\headerl}{%
 \thispagestyle{empty}
\noindent
\hspace{-6mm}
\begin{minipage}[t][14mm][b]{169mm}
 \fontsize{10}{11}\selectfont\textcolor{grey0}{%
 GKB100: 
Fluid mechanics in the spirit of G. K. Batchelor\\ 
   \fontsize{8}{10}\selectfont
15-18 March 2020, DAMTP, Centre for Mathematical Sciences, Cambridge, UK\\[-5pt]
\hrule}%
 \end{minipage}
\vspace{2pt}}%
%
\newcommand{\correspond}{%
\hspace{-6mm}
\begin{minipage}[t][12pt][b]{169mm}
 \hfill\fontsize{10}{11.2}\selectfont\textcolor{grey0}{$^*$corresponding author: \@email }\par
 \end{minipage}
}%
%
% Title
\newcommand{\aff}[1]{$^{\textnormal {#1}}$}
\newcommand{\corr}{$^{*}$}
\newcommand{\email}[1]{\def\@email{#1}}
\newcommand{\address}[1]{\def\@address{#1}}
\renewcommand{\maketitle}{%
\begin{center}%
  \vspace{0pt}%
  {%
   \fontsize{12}{14}\selectfont
   \bfseries
    \@title
   \par
  }%
 \vspace{7pt}%
  {%
\fontsize{11}{12.2}\selectfont
   \@author
   \par
  }%
  \vspace{5pt}%
  {%
\fontsize{10}{11.2}\selectfont
   \normalfont\@address
   \par
  }%
\end{center}
 \vspace{-3pt plus 0.2pt minus 0.2pt}%
}%
% Body text
\setcounter{secnumdepth}{-2}
\renewcommand\section{\@startsection{section}{1}{0pt}%
                                  {6pt plus 0.5pt minus 1pt}%
                                  {.2pt plus .2pt}%
                                  {\fontsize{11}{12.2}\selectfont\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{0pt}%
                                  {2pt plus 4pt minus 4pt}%
                                  {-2ex plus -2ex minus -0.2ex}%
                                  {\normalfont\itshape}}
\renewcommand{\figurename}{Fig.}
\setlength{\belowcaptionskip}{-6pt}
\setlength{\abovecaptionskip}{3pt}
\newenvironment{GKB100-list}
{\begin{list}{$\bullet$}{%
\setlength\itemindent{-6pt}
\setlength\leftmargin{12pt}
\setlength\labelsep{6pt}
\setlength\labelwidth{0pt}
\setlength\topsep{0pt}
\setlength\partopsep{0pt}
\setlength\listparindent{0pt}
\setlength\parsep{0pt}
\setlength\itemsep{-1pt}
}}
{\end{list}}
%
\newcounter{enumem}
\newenvironment{GKB100-num}
{\begin{list}{\arabic{enumem}.}{%
\setlength\itemindent{-6pt}
\setlength\leftmargin{12pt}
\setlength\labelsep{6pt}
\setlength\labelwidth{0pt}
\setlength\topsep{0pt}
\setlength\partopsep{0pt}
\setlength\listparindent{0pt}
\setlength\parsep{0pt}
\setlength\itemsep{-1pt}
\usecounter{enumem}
}}%
{\end{list}}
%
\AtBeginDocument{%
\headerl
\maketitle
}%
\AtEndDocument{%
\vspace{-9pt}\vfil
\correspond
}%
%
% the bibliography
\newenvironment{references}[1]{\begin{thebibliography}{#1}\parskip-4pt}{\end{thebibliography}}
%
\endinput